@@ -55,8 +55,7 @@ from __future__ import (absolute_import, division, print_function,
 
 import numpy as np
 from scipy import ndimage
-from tomopy.util.misc import fft2
-import dxchange
+from tomopy.util.misc import fft2, write_tiff
 from scipy.optimize import minimize
 from skimage.feature import register_translation
 from tomopy.misc.corr import circ_mask
@@ -347,7 +346,7 @@ def _create_mask(nrow, ncol, radius, drop):
         Image height.
     ncol : int
         Image width.
-    radius: int 
+    radius: int
         Radius of an object, in pixel unit.
     drop : int
         Drop lines around vertical center of the mask.
@@ -392,7 +391,7 @@ def find_center_pc(proj1, proj2, tol=0.5, rotc_guess=None):
     tol : scalar, optional
         Subpixel accuracy
 
-    rotc_guess : float, optional 
+    rotc_guess : float, optional
         Initual guess value for the rotation center
 
     Returns
@@ -553,9 +552,7 @@ def write_center(
 
     # Save images to a temporary folder.
     for m in range(len(center)):
-        fname = os.path.join(
-            dpath, str('{0:.2f}'.format(center[m]) + '.tiff'))
-        dxchange.write_tiff(rec[m], fname=fname, overwrite=True)
+        write_tiff(data=rec[m], fname=dpath, digit='{0:.2f}'.format(center[m]))
 
 
 def mask_empty_slice(tomo, threshold=0.25):
